@@ -7,19 +7,24 @@
 //! arbitrary indices use [`FactoryVecDeque`].
 //!
 //! Also, [`FactoryVec`] works with all container widgets that implement
-//! [`SimpleFactoryView`](super::SimpleFactoryView) such as [`gtk::Box`] or [`gtk::Grid`].
+//! [`FactoryView`](super::FactoryView) such as [`gtk::Box`] or [`gtk::Grid`].
 //!
 //! [`FactoryVecDeque`] additionally needs container widgets to implement the
 //! [`FactoryListView`](super::FactoryListView) trait that's implements support
 //! for adding and removing widgets at arbitrary positions.
 //! [`gtk::Grid`] for example only works with [`FactoryVec`] but not with
 //! [`FactoryVecDeque`] because widgets can't be inserted at arbitrary positions.
+//!
+//! Another difference is that [`FactoryVecDeque`] will insert widgets
+//! at the beginning if the container used for the factory contains other widgets
+//! that were inserted independently from the factory.
+//! Yet, [`FactoryVec`] will insert widgets at the end in the same scenario.
 
 mod factory_vec;
 mod factory_vec_deque;
 
 pub use factory_vec::FactoryVec;
-pub use factory_vec_deque::{DynamicIndex, FactoryVecDeque};
+pub use factory_vec_deque::{DynamicIndex, FactoryVecDeque, WeakDynamicIndex};
 
 use std::fmt::Debug;
 
