@@ -13,10 +13,12 @@
     html_favicon_url = "https://raw.githubusercontent.com/AaronErhardt/relm4/main/assets/Relm_logo.svg"
 )]
 
+pub mod actions;
 mod app;
 mod component;
 pub mod drawing;
 pub mod factory;
+mod micro_component;
 mod msg_handler;
 mod traits;
 pub mod util;
@@ -24,6 +26,7 @@ mod worker;
 
 pub use app::RelmApp;
 pub use component::RelmComponent;
+pub use micro_component::{MicroComponent, MicroComponentError, MicroModel, MicroWidgets};
 pub use msg_handler::RelmMsgHandler;
 pub use traits::*;
 pub use util::widget_plus::WidgetPlus;
@@ -43,6 +46,13 @@ type Application = adw::Application;
 #[cfg(not(feature = "libadwaita"))]
 type Application = gtk::Application;
 
+// Re-exports
+#[cfg(feature = "macros")]
+pub use relm4_macros::*;
+
+#[cfg(feature = "libadwaita")]
+pub use adw;
+
 #[cfg(feature = "tokio-rt")]
 #[cfg_attr(doc, doc(cfg(feature = "tokio-rt")))]
 /// Re-export of [`async_trait::async_trait`]
@@ -109,12 +119,12 @@ pub fn spawn_future<F: futures_core::future::Future<Output = ()> + Send + 'stati
     gtk::glib::MainContext::ref_thread_default().spawn(f);
 }
 
-/// Send a message with a sender.
+/// A short macro for conveniently sending messages.
 ///
-/// The sender is automatically cloned and the [`Result`] is unwrapped.
+/// The message is sent using the sender and the [`Result`] is unwrapped automatically.
 #[macro_export]
 macro_rules! send {
-    ($sender:ident, $msg:expr) => {
+    ($sender:expr, $msg:expr) => {
         $sender.send($msg).expect("Receiver was dropped!")
     };
 }
